@@ -65,7 +65,7 @@ class TenantLakehouseSQL():
         databricksSql = DatabricksSql()
 
         databricksSql.connect(server_hostname=server_hostname, http_path=http_path, pas=pat)
-        logging.info('Executing SQL query.')
+        logging.debug('Executing SQL query.')
         query_result = databricksSql.query(sql_query)
         return query_result
 
@@ -105,7 +105,7 @@ class TenantLakehouseSQL():
         databricksSql = DatabricksSql()
 
         databricksSql.connect(server_hostname=server_hostname, http_path=http_path, pas=pat)
-        logging.info('Executing SQL query.')
+        logging.debug('Executing SQL query.')
         cursor = databricksSql.get_cursor()
         return cursor        
 
@@ -118,6 +118,6 @@ class TenantLakehouseSQL():
         pat = os.environ['default_pat']
 
         databricksSql.connect(server_hostname=server_hostname, http_path=http_path, pas=pat)
-        logging.info('Executing SQL query.')
+        logging.debug('Executing SQL query.')
         cursor = databricksSql.get_cursor()
         return cursor 
\ No newline at end of file
